Changelog
=========

These are the notable changes for each django-ldap3-sync release. For
additional detail, read the complete [Commit History](https://github.com/pgower/django-ldap3-sync/commits/).

**django-ldap3-sync 0.1.2**
   * Fork django-ldap-sync
   * Add group membership synchronisation
   * Rewrite to use ldap3 as ldap library

**django-ldap-sync 0.1.1**
   * Fix exception with AD internal referrals

**django-ldap-sync 0.1.0**
   * Initial release
